@@ -1,25 +1,28 @@
-# (c) Copyright IBM Corp. 2010, 2017. All Rights Reserved.
+# (c) Copyright IBM Corp. 2010, 2022. All Rights Reserved.
 
 """Pytest Fixture for Testing Resilient Circuits Components"""
-from __future__ import print_function
 
+import calendar
+import json
+import logging
 import os
 import sys
 import time
-import calendar
-import json
 import traceback
-import logging
+
 import pytest
-from pytest_resilient_circuits.circuits_fixtures import manager, watcher
 import resilient
-from resilient import SimpleHTTPException
 import resilient_circuits.app
+from resilient_circuits import rest_helper
+from resilient import SimpleHTTPException
+
+from pytest_resilient_circuits.circuits_fixtures import manager, watcher
+from pytest_resilient_circuits.shared_mock_data import mock_constants
 
 """
 Depending on which version of python we are on
-we may either need to import the StringIO package 
-or the io package which contains the equivelant class on that platform
+we may either need to import the StringIO package
+or the io package which contains the equivalent class on that platform
 """
 if sys.version_info.major < 3:
     from StringIO import StringIO
@@ -46,11 +49,17 @@ class ConfiguredAppliance:
         org = os.environ.get("TEST_RESILIENT_ORG", request.config.option.resilient_org)
         user = os.environ.get("TEST_RESILIENT_USER", request.config.option.resilient_email)
         password = os.environ.get("TEST_RESILIENT_PASSWORD", request.config.option.resilient_password)
-        assert all((host, org, user, password))
+        api_key_id = os.environ.get("TEST_RESILIENT_API_KEY_ID", request.config.option.resilient_api_key_id)
+        api_key_secret = os.environ.get("TEST_RESILIENT_API_KEY_SECRET", request.config.option.resilient_api_key_secret)
+
+        assert all([host, org]) and (all([user, password]) or all([api_key_id, api_key_secret]))
 
         # Connect to Resilient
         self.client = resilient.SimpleClient(org_name=org, base_url=url, verify=False)
-        session = self.client.connect(user, password)
+        if api_key_id is not None:
+            self.client.set_api_key(api_key_id=api_key_id, api_key_secret=api_key_secret)
+        else:
+            self.client.connect(user, password)
 
         # Retrieve constants from appliance
         constants = self._get_constants()["actions_framework"]
@@ -396,6 +405,20 @@ port = 443
         if password:
             config_parser.set(RESILIENT, "password", password)
 
+        api_key_id = os.environ.get("TEST_RESILIENT_API_KEY_ID")
+        if api_key_id:
+            print("TEST api_key_id={} (from environment)".format(api_key_id))
+        else:
+            api_key_id = request.config.option.resilient_api_key_id
+            print("TEST api_key_id={} (from configuration data)".format(api_key_id))
+
+        if api_key_id:
+            config_parser.set(RESILIENT, "api_key_id", api_key_id)
+
+        api_key_secret = os.environ.get("TEST_RESILIENT_API_KEY_SECRET", request.config.option.resilient_api_key_secret)
+        if api_key_secret:
+            config_parser.set(RESILIENT, "api_key_secret", api_key_secret)
+
         # common values
         config_parser.set(RESILIENT, "no_prompt_password", "True")
         config_parser.set(RESILIENT, "test_actions", "True")
@@ -418,13 +441,19 @@ port = 443
         # Set this manually b/c it is only read on import in app.py
         resilient_circuits.app.APP_CONFIG_FILE = config_file.strpath
 
+        # Check if is_selftest param was set
+        is_selftest = False
+
+        if hasattr(request, "param") and request.param.get("IS_SELFTEST"):
+            is_selftest = True
+
         self.manager = manager
         self.watcher = watcher
 
         # Remove the pytest commandline arguments so they don't break ArgParse in resilient
         sys.argv = sys.argv[0:1]
 
-        self.app = resilient_circuits.app.App().register(manager)
+        self.app = resilient_circuits.app.App(IS_SELFTEST=is_selftest).register(manager)
         assert watcher.wait("registered")
         pytest.wait_for(manager, "_running", True)
         assert watcher.wait("load_all_success", timeout=10)
@@ -448,6 +477,28 @@ port = 443
 # end ResilientCircuits
 
 
+"""
+Shared pytest fixtures
+
+Note:
+    -   Code after the 'yield' statement in a fixture
+        is ran after the test (or scope i.e. test session) has complete
+    -   fx_ prefixes a 'fixture'
+    -   Put fixture logic in separate 'private' function so we
+        can share logic between fixtures
+    -   Fixture must have BEFORE and AFTER docstring
+"""
+
+
+@pytest.fixture(scope="function")
+def fx_mock_resilient_client():
+    """
+    Before: Creates a mock instance of get_resilient_client
+    After: N/A
+    """
+    yield rest_helper.get_resilient_client(opts=mock_constants.MOCK_APP_CONFIGS)
+
+
 @pytest.fixture(scope="class")
 def circuits_app(tmpdir_factory, manager, watcher, request):
     circuits_app_fixture = ResilientCircuits(tmpdir_factory, manager, watcher, request)
